##
## interfaces.py
import grok
from zope import schema
from waeup.interfaces import IBaseItem

class IStudent(IBaseItem):
    """Representation of a student.
    """
    entry_mode = schema.ASCIILine( # Choice?
        title = u'Entry Mode',
        default = '',
        required = False,
        )
    end_level = schema.Int(
        title = u'End Level',
        default = 400,
        missing_value = 0,
        required = True,
        min=0,
        max=600
        )
    name = schema.TextLine(
        title = u'Name of student',
        default = u'Nobody',
        required = True,
        )
    jamb_reg_no = schema.ASCIILine(
        title = u'JAMB Reg. No.',
        default = '',
        required = False,
        )
    level = schema.Int(
        title = u'Level',
        default = 0,
        missing_value = 0,
        required = False,
        min = 0,
        max = 600
        )
    id = schema.ASCIILine(
        title = u'Student ID',
        default = '',
        required = False,
        constraint=(re.compile("^[A-Z]\d{6}$").match)
        )
    lga = schema.TextLine(
        title = u'LGA', # Bundesstaat/Bezirk
        default = u'',
        required = False,
        description = u'federal state / county'
        )
    entry_session = schema.Int(
        title = u'Entry Session',
        default = -1,
        missing_value = 0,
        required = False,
        min=-1,
        max=7
        )
    matric_no = schema.ASCIILine(
        title = u'Matric No.',
        default = '',
        required = False,
        constraint=re.compile("^[A-Z]{3}\d{7}$").match
        )
    sex = schema.ASCIILine( # Choice!
        title = u'Sex',
        default = u'M',
        required = True,
        constraint=(re.compile("^[MF]$").match)
        )
    phone = schema.TextLine(
        title = u'Phone',
        default = u'',
        required = False,
        constraint=re.compile(u"^[\d-,]{5,}$").match,
        description = u'if multiple, separate with comma'
        )
    session = schema.ASCIILine(
        title = u'Session',
        default = '1',
        required = False,
        constraint=(re.compile("^\d$").match)
        )
    course = schema.ASCIILine( # Choice
        title = u'Course',
        default = '',
        required = False,
        constraint=(re.compile("^[A-Z]{3,8}$").match)
        )
    mode = schema.ASCIILine( # Choice?
        title = u'Mode',
        default = '',
        required = False,
        )
    faculty = schema.ASCIILine( # Choice
        title = u'Faculty',
        default = '',
        required = False,
        constraint=(re.compile("^[A-Z]{3}$").match)
        )
    department = schema.ASCIILine( # Choice
        title = u'Department',
        default = '',
        required = False,
        constraint=(re.compile("^[A-Z]{3}$").match)
        )
    verdict = schema.ASCIILine(
        title = u'Verdict',
        default = '',
        required = False,
        )
    review_state = schema.ASCIILine( # Choice
        title = u'Review State',
        default = 'student_created',
        required = True,
        )
    perm_address = schema.Text(
        title = u'Permanent Address',
        default = u'',
        required = True,
        )
    email = schema.ASCIILine(
        title = u'Email',
        default = '',
        required = True,
        constraint=(re.compile("^[\w\.]+@(\w+\.)+\w{2,}$").match)
        )
